/* Name: _bezier.h
 * Purpose: header file for _bezier.c
 * Author: Ken McIvor <mcivken@iit.edu>
 *
 * Copyright 2003-2004 Illinois Institute of Technology
 *
 * See the file "LICENSE" for information on usage and redistribution
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 */


#ifndef __BEZIER_H
#define __BEZIER_H

#include <stdio.h>

#ifdef __cplusplus
extern "C" {
#endif


#define _bezier_API_pointers 4

#define _bezier_pyCoeff_NUM 0
#define _bezier_pyCoeff_RETURN PyObject *
#define _bezier_pyCoeff_PROTO (PyObject *, PyObject *)

#define _bezier_pyBint_NUM 1
#define _bezier_pyBint_RETURN PyObject *
#define _bezier_pyBint_PROTO (PyObject *, PyObject *)

#define _bezier_coeff_NUM 2
#define _bezier_coeff_RETURN void
#define _bezier_coeff_PROTO (PyArrayObject *)

#define _bezier_bint_NUM 3
#define _bezier_bint_RETURN void
#define _bezier_bint_PROTO (double, PyArrayObject *, PyArrayObject *, PyArrayObject *, PyArrayObject *)


#ifdef _BEZIER_MODULE

static _bezier_pyCoeff_RETURN _bezier_pyCoeff _bezier_pyCoeff_PROTO;
static _bezier_pyBint_RETURN _bezier_pyBint _bezier_pyBint_PROTO;
static _bezier_coeff_RETURN _bezier_coeff _bezier_coeff_PROTO;
static _bezier_bint_RETURN _bezier_bint _bezier_bint_PROTO;

#else

static void **_bezier_API;

#define _bezier_pyCoeff \
 (*(_bezier_pyCoeff_RETURN (*)_bezier_pyRead_PROTO) \
  _bezier_API[_bezier_pyCoeff_NUM])

#define _bezier_pyBint \
 (*(_bezier_pyBint_RETURN (*)_bezier_pyBint_PROTO) \
  _bezier_API[_bezier_pyBint_NUM])

#define _bezier_coeff \
 (*(_bezier_coeff_RETURN (*)_bezier_coeff_PROTO) \
  _bezier_API[_bezier_coeff_NUM])

#define _bezier_bint \
 (*(_bezier_bint_RETURN (*)_bezier_bint_PROTO) \
  _bezier_API[_bezier_bint_NUM])

#define import__bezier() \
{ \
  PyObject *module = PyImport_ImportModule("xdp.interpolate._bezier"); \
  if (module != NULL) { \
    PyObject *module_dict = PyModule_GetDict(module); \
    PyObject *c_api_object = PyDict_GetItemString(module_dict, "_C_API"); \
    if (PyCObject_Check(c_api_object)) { \
      _bezier_API = (void **)PyCObject_AsVoidPtr(c_api_object); \
    } \
  } \
}

#endif /* _BEZIER_MODULE */
 

#ifdef __cplusplus
}
#endif

#endif /* __BEZIER_H */
