# Name: xdp/stats.py
# Purpose: XDP vector-oriented statistics
# Author: Ken McIvor <mcivken@iit.edu>
#
# Copyright 2003-2004 Illinois Institute of Technology
#
# See the file "LICENSE" for information on usage and redistribution
# of this file, and for a DISCLAIMER OF ALL WARRANTIES.

"""xdp.stats

This module provides primitive (Numeric array-based) functions for calculating
statistics.
"""


import math
import Numeric


def mean(A):
    """Calculate the arithmetic mean of the values of the Numeric array 'A'.
    """

    return Numeric.average(A, axis=None)


def moment(N, A, C):
    """Calculates the 'N'th moment of the of the Numeric array 'A' using the
    center 'C'.
    """
    return Numeric.average((A - C)**N, axis=None)


def stddev(A, mean=None):
    """Calculates the standard deviation of the numeric array 'A'.

    The arithmetic mean may be provided using the keyword argument 'mean'.  If
    it is not provided it will be calculated.
    """

    if mean is None:
        mean = Numeric.average(A, axis=None)

    return math.sqrt(moment(2, A, mean))


# TODO: add all of Carlo's statistics stuff.
